var toml = require('toml');
var moment = require('moment');
var path = require('path');
var jsesc = require('jsesc')

var readPageWorker = function(content, articleName) {
  if(content === undefined) throw new Error("content is undefined");
  var head = content.substring(0,4)
  if(head !== '+++\n')
    throw new Error('Failed to parse file '+articleName+':\n'+
                    'Wrong header (expected "+++\\n" got "'+jsesc(head)+'")')

  content = content.substring(4);
  var fm_end = content.indexOf("+++\n");
  if(fm_end < 0) {
    console.log(jsesc(content));
    throw new Error('Cannot find terminating +++\n in file '+articleName);
  }
  var obj = {};
  obj.content = content.substring(fm_end+4);
  try {
    obj.metadata = toml.parse(content.substring(0,fm_end-1)+"\n");
  } catch(e) {
    console.log(articleName+": Failed to parse metadata");
    throw e;
  }
  if(obj.metadata.date && obj.metadata.date.creation) obj.metadata.date.creation = moment(obj.metadata.date.creation);
  return obj;
}

module.exports = function(obj) {
  return new Promise(function(resolve, reject) {
    var pages = [];
    obj.pages.forEach(function(page) {
      pages.push(readPageWorker(page.content, page.filename));
    })
    obj.pages = pages;
    resolve(obj);
  });
}
